==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+47"/>
        <source>Status Bar Font:</source>
        <translation>Pisava statusne vrstice:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation>Gradniki statusne vrstice</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation>Prikaz koordinat</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation>Prikaz miške</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation>Prikaz izbora</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation>Prikaz napredka</translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translation>Gradniki</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translation>Statusna vrstica</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation>&amp;Statusna vrstica</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+53"/>
        <source>Status Bar Font:</source>
        <translation>Pisava statusne vrstice:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation>Gradniki statusne vrstice</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation>Prikaz koordinat</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation>Prikaz miške</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation>Prikaz izbora</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation>Prikaz napredka</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Show status tips</source>
        <translation>Prikaži namige stanj</translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translation>Gradniki</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translation>Statusna vrstica</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation>&amp;Statusna vrstica</translation>
    </message>
</context>
</TS>
